import 'dart:core';

class Measurement {
  int measurementID;
  DateTime timeMeasured;
  Sensor sensor;
  List<Data> dataList;
  List<Corner> cornerList;
  String bodyOfWater;

  Measurement({
    required this.measurementID,
    required this.timeMeasured,
    required this.sensor,
    required this.dataList,
    required this.cornerList,
    required this.bodyOfWater,
  });

  factory Measurement.Measurement(Map<String, dynamic> json) {
    return Measurement(
      measurementID: json['MeasurementID'],
      timeMeasured: DateTime.parse(json['TimeMeasured']),
      sensor: Sensor.fromJson(json['Sensor']),
      dataList: (json['Data'] as List<dynamic>)
          .map((data) => Data.fromJson(data))
          .toList(),
      cornerList: (json['Corners'] as List<dynamic>)
          .map((data) => Corner.fromJson(data))
          .toList(),
      bodyOfWater: json['WaterBodyName'],
      /*
            dataList: (json['Data'] != null && json['Data'] is List)
          ? (json['Data'] as List<dynamic>).map((data) => Data.fromJson(data)).toList()
          : [],
      cornerList: (json['Corner'] != null && json['Corner'] is List)
          ? (json['Corner'] as List<dynamic>).map((data) => Corner.fromJson(data)).toList()
          : [],
      bodyOfWater: json['WaterBodyName'] ?? '',
      */
    );
  }
}

class Sensor {
  int sensorID;
  String sensorType;
  bool active;

  Sensor({
    required this.sensorID,
    required this.sensorType,
    required this.active,
  });

  factory Sensor.fromJson(Map<String, dynamic> json) {
    return Sensor(
      sensorID: json['SensorID'],
      sensorType: json['SensorType'],
      active: json['Active'],
    );
  }
}

class Data {
  double latitude;
  double longitude;
  double iceTop;
  double iceBottom;
  double calculatedThickness;
  double accuracy;

  Data({
    required this.latitude,
    required this.longitude,
    required this.iceTop,
    required this.iceBottom,
    required this.calculatedThickness,
    required this.accuracy,
  });

  factory Data.fromJson(Map<String, dynamic> json) {
    return Data(
      latitude: json['Latitude'],
      longitude: json['Longitude'],
      iceTop: json['IceTop'],
      iceBottom: json['IceBottom'],
      calculatedThickness: json['CalculatedThickness'],
      accuracy: json['Accuracy'],
    );
  }
}

class Corner {
  int cornerID;
  double latitude;
  double longitude;

  Corner({
    required this.cornerID,
    required this.latitude,
    required this.longitude,
  });

  factory Corner.fromJson(Map<String, dynamic> json) {
    return Corner(
      cornerID: json['CornerID'],
      latitude: json['Latitude'],
      longitude: json['Longitude'],
    );
  }
}