import 'package:flutter/material.dart';
import '../marker_handler/marker_data.dart';
import '../consts.dart';
import 'quick_view_chart.dart';
import 'stat_charts.dart';
import 'osm_map.dart';
import 'sat_layer.dart';

class MapContainerWidget extends StatefulWidget {
  final List<Measurement> markerList;

  const MapContainerWidget({Key? key, required this.markerList}) : super(key: key);

  @override
  _MapContainerWidgetState createState() => _MapContainerWidgetState();
}

class _MapContainerWidgetState extends State<MapContainerWidget> {

  Measurement? selectedMarker; // Containing data for selected marker
  bool isMinimized = true; // Quick view box state tacker
  bool satLayer = false; // Satellite layer visibility tracker

  @override
  Widget build(BuildContext context) {

    const double contPadding = 30; // Container padding space

    return LayoutBuilder(
      builder: (context, constraints) {
        double screenWidth = constraints.maxWidth;
        double boxWidth = 0.86;
        double boxHeight = 1.4;
        return Column(
          children: [
            const SizedBox(height: contPadding),
            /*if (true) NB: add search bar
              const SearchBar(),
              const SizedBox(height: contPadding),*/
            ClipRRect(
              borderRadius: BorderRadius.circular(20),
              child: Stack( // Stack of quick view, map layer, satellite layer, and buttons
                children: [
                  SizedBox(
                    width: screenWidth * boxWidth,
                    height: screenWidth * boxHeight,
                    child: OSMmap(markerList: widget.markerList), // OpenStreetMap layer
                  ),
                  SizedBox(
                    width: screenWidth * boxWidth,
                    height: screenWidth * boxHeight,
                    child: Stack(
                      children: [
                        SatLayer(markerList: widget.markerList), // Satellite layer
                        Visibility(
                          visible: satLayer, // Only show layer if satellite button is toggled on
                          child: SatLayer(markerList: widget.markerList),
                        ),
                      ],
                    ),
                  ),
                  Positioned( // Quick view box layered over map
                    bottom: 10,
                    right: 10,
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(10),
                      child: Container(
                        width: (screenWidth * boxWidth) / 2.4,
                        height: isMinimized ? 20 : (screenWidth * boxWidth) / 2.4,
                        color: Colors.blue.withOpacity(0.7),
                        child: Stack(
                          children: [
                            Visibility( // Graph only visible when box is maximized and a marker is selected
                              visible: !isMinimized && selectedMarker != null,
                              child: Center(
                                child: Padding(
                                  padding: const EdgeInsets.only(right: 16.0, top: 17.0),
                                  child: SizedBox(
                                    width: (screenWidth * boxWidth) / 2.3,
                                    height: (screenWidth * boxWidth) / 2.3,
                                    child: const QuickViewChart(), // Quick view graph
                                  ),
                                ),
                              ),
                            ),
                            Positioned(
                              top: 0,
                              right: 5,
                              child: GestureDetector(
                                onTap: () {
                                  setState(() {
                                    isMinimized = !isMinimized; // Toggle minimized state
                                  });
                                },
                                child: Icon(isMinimized ? Icons.arrow_drop_up : Icons.arrow_drop_down),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                  Positioned( // Satellite button
                    top: 10,
                    right: 10,
                    child: GestureDetector(
                      onTap: () {
                        setState(() {
                          satLayer = !satLayer; // Toggle satellite layer state on press
                        });
                        print("satLayer? : $satLayer");
                      },
                      child: Container(
                        padding: const EdgeInsets.all(8),
                        decoration: satLayer ? const BoxDecoration( // Add decoration only when pressed
                          shape: BoxShape.circle,
                          color: Colors.blue,
                        ) : null,
                        child: const Icon(Icons.satellite_alt_outlined),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            const SizedBox(height: contPadding), // Padding between containers
            ClipRRect(
              borderRadius: BorderRadius.circular(20),
              child: SizedBox(
                width: screenWidth * boxWidth,
                height: screenWidth * boxHeight * 1.5, // NB: make dynamic
                child: Align(
                  alignment: Alignment.topLeft,
                  child: Padding(
                    padding: const EdgeInsets.only(top: 20, left: 20), // Edge padding, text
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                         Text(
                          'Ice stats',
                          style: titleStyle,
                        ),
                        Text(
                          'Time of measurement: ${selectedMarker?.timeMeasured}',
                          style: regTextStyle,
                        ),
                        Text(
                          'Location: (placeholder, placeholder)',
                          style: regTextStyle,
                        ),
                        const SizedBox(height: contPadding),
                        const StatCharts(),
                      ],
                    ),
                  ),
                ),
              ),
            ),
          ],
        );
      },
    );
  }
}